==> qtjambi-remoteobjects-6.5.3-sources.jar: io/qt/remoteobjects/QRemoteObjectRegistry.java <==
package io.qt.remoteobjects;

import io.qt.*;


/**
 * <p>A class holding information about Source objects available on the Qt Remote Objects network</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qremoteobjectregistry.html">QRemoteObjectRegistry</a></code></p>
 */
public final class QRemoteObjectRegistry extends io.qt.remoteobjects.QRemoteObjectReplica
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRemoteObjectRegistry.class);
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qremoteobjectregistry.html#remoteObjectAdded">QRemoteObjectRegistry::<wbr>remoteObjectAdded(QRemoteObjectSourceLocation)</a></code></p>
     */
    public final @NonNull Signal1<io.qt.core.@NonNull QPair<java.lang.@NonNull String, io.qt.remoteobjects.@NonNull QRemoteObjectSourceLocationInfo>> remoteObjectAdded = new Signal1<>();

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qremoteobjectregistry.html#remoteObjectRemoved">QRemoteObjectRegistry::<wbr>remoteObjectRemoved(QRemoteObjectSourceLocation)</a></code></p>
     */
    public final @NonNull Signal1<io.qt.core.@NonNull QPair<java.lang.@NonNull String, io.qt.remoteobjects.@NonNull QRemoteObjectSourceLocationInfo>> remoteObjectRemoved = new Signal1<>();
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qremoteobjectregistry.html#sourceLocations-prop">QRemoteObjectRegistry::<wbr>bindableSourceLocations()const</a></code></p>
     */
    @QtPropertyBindable(name="sourceLocations")
    @QtUninvokable
    public final io.qt.core.@NonNull QBindable<java.util.@NonNull Map<java.lang.@NonNull String, io.qt.remoteobjects.@NonNull QRemoteObjectSourceLocationInfo>> bindableSourceLocations(){
        return bindableSourceLocations_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QBindable<java.util.Map<java.lang.String, io.qt.remoteobjects.QRemoteObjectSourceLocationInfo>> bindableSourceLocations_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qremoteobjectregistry.html#sourceLocations">QRemoteObjectRegistry::<wbr>sourceLocations()const</a></code></p>
     */
    @QtPropertyReader(name="sourceLocations")
    @QtPropertyStored("false")
    @QtUninvokable
    public final io.qt.core.@NonNull QHash<java.lang.@NonNull String, io.qt.remoteobjects.@NonNull QRemoteObjectSourceLocationInfo> sourceLocations(){
        return sourceLocations_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QHash<java.lang.String, io.qt.remoteobjects.QRemoteObjectSourceLocationInfo> sourceLocations_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QRemoteObjectRegistry::<wbr>registerMetatypes()</code></p>
     */
    public native static void registerMetatypes();
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QRemoteObjectRegistry(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Kotlin property getter. In Java use {@link #sourceLocations()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.core.@NonNull QHash<java.lang.@NonNull String, io.qt.remoteobjects.@NonNull QRemoteObjectSourceLocationInfo> getSourceLocations() {
        return sourceLocations();
    }
}

==> qtjambi-remoteobjects-6.7.1-sources.jar: io/qt/remoteobjects/QRemoteObjectRegistry.java <==
package io.qt.remoteobjects;

import io.qt.*;


/**
 * <p>A class holding information about Source objects available on the Qt Remote Objects network</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qremoteobjectregistry.html">QRemoteObjectRegistry</a></code></p>
 */
public final class QRemoteObjectRegistry extends io.qt.remoteobjects.QRemoteObjectReplica
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRemoteObjectRegistry.class);
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qremoteobjectregistry.html#remoteObjectAdded">QRemoteObjectRegistry::<wbr/>remoteObjectAdded(QRemoteObjectSourceLocation)</a></code></p>
     */
    public final @NonNull Signal1<io.qt.core.@NonNull QPair<java.lang.@NonNull String, io.qt.remoteobjects.@NonNull QRemoteObjectSourceLocationInfo>> remoteObjectAdded = new Signal1<>();

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qremoteobjectregistry.html#remoteObjectRemoved">QRemoteObjectRegistry::<wbr/>remoteObjectRemoved(QRemoteObjectSourceLocation)</a></code></p>
     */
    public final @NonNull Signal1<io.qt.core.@NonNull QPair<java.lang.@NonNull String, io.qt.remoteobjects.@NonNull QRemoteObjectSourceLocationInfo>> remoteObjectRemoved = new Signal1<>();
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qremoteobjectregistry.html#sourceLocations-prop">QRemoteObjectRegistry::<wbr/>bindableSourceLocations()const</a></code></p>
     */
    @QtPropertyBindable(name="sourceLocations")
    @QtUninvokable
    public final io.qt.core.@NonNull QBindable<java.util.@NonNull Map<java.lang.@NonNull String, io.qt.remoteobjects.@NonNull QRemoteObjectSourceLocationInfo>> bindableSourceLocations(){
        return bindableSourceLocations_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QBindable<java.util.Map<java.lang.String, io.qt.remoteobjects.QRemoteObjectSourceLocationInfo>> bindableSourceLocations_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qremoteobjectregistry.html#sourceLocations">QRemoteObjectRegistry::<wbr/>sourceLocations()const</a></code></p>
     */
    @QtPropertyReader(name="sourceLocations")
    @QtPropertyStored("false")
    @QtUninvokable
    public final io.qt.core.@NonNull QHash<java.lang.@NonNull String, io.qt.remoteobjects.@NonNull QRemoteObjectSourceLocationInfo> sourceLocations(){
        return sourceLocations_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QHash<java.lang.String, io.qt.remoteobjects.QRemoteObjectSourceLocationInfo> sourceLocations_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QRemoteObjectRegistry::<wbr/>registerMetatypes()</code></p>
     */
    public native static void registerMetatypes();
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    private QRemoteObjectRegistry(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #sourceLocations()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.core.@NonNull QHash<java.lang.@NonNull String, io.qt.remoteobjects.@NonNull QRemoteObjectSourceLocationInfo> getSourceLocations() {
        return sourceLocations();
    }
}
